" Vim syntax file
" Language:    CERNLIB kumac (Kit for a User interface MACro) files (for PAW)
" Maintainer:  Kevin B. McCarty <kmccarty@debian.org>

au BufNewFile,BufRead *.kumac set filetype=kumac
au BufNewFile,BufRead *.kumacold set filetype=kumac
au BufNewFile,BufRead .kumacs set filetype=kumac
